@@ -1,6 +1,19 @@
-# file MASS/gamma.shape.q
+# file MASS/R/gamma.shape.R
 # copyright (C) 1994-9 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 gamma.shape <- function(object, ...) UseMethod("gamma.shape")
 
 gamma.shape.glm <- function(object, it.lim = 10,
@@ -11,7 +24,7 @@ gamma.shape.glm <- function(object, it.lim = 10,
     y <- object$y
     A <- object$prior.weights
     if(is.null(A)) A <- rep(1, length(y))
-    u <- object$fitted
+    u <- object$fitted.values
     Dbar <- object$deviance/object$df.residual
     alpha <- (6 + 2*Dbar)/(Dbar*(6 + Dbar))
     if(verbose) {
@@ -37,12 +50,12 @@ gamma.shape.glm <- function(object, it.lim = 10,
 }
 
 gamma.dispersion <- function(object, ...)
-    1/gamma.shape(object, ...)[[1]]
+    1/gamma.shape(object, ...)[[1L]]
 
 print.gamma.shape <- function(x, ...)
 {
     y <- x
-    x <- array(unlist(x), dim = 2:1,
+    x <- array(unlist(x), dim = 2L:1L,
                dimnames = list(c("Alpha:", "SE:"), ""))
     NextMethod("print")
     invisible(y)
